use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alan
Alders
Alessandro
Berry
Brad
Bright
CA
CGI
Chris
Christian
Claes
Clinton
Cook
Craig
David
Davis
Dean
Doherty
Edward
Eklund
Etheridge
Evans
Felipe
Gardner
Gasper
Ghedini
Gilbert
Golden
Gormley
Grazzini
Greg
Guimard
HTTP
Hansen
Horsfall
Hukins
Jakobsson
James
Jeremy
Jess
Kaji
Karen
Keenan
Kennedy
Kornetzki
Lukas
Martin
Mates
Matthew
Mengué
Michael
Mike
Mitchell
Miyagawa
Nehren
Nicolas
Olaf
Olivier
Pearce
Petr
Písař
Raspass
Robinson
Rochelemagne
Serguei
Shoichi
Sinan
SkyMarshal
Steve
Syohei
Sören
Tatsuhiko
Tiny
Tom
Tony
Trouchelle
UA
Unur
Weyl
Xavier
YOSHIDA
Zborowski
al3xbio
apeiron
bgills
brian
carlson
castaway
cberry
chansen
claes
clint
craigberry
cweyl
dagolden
davem
doherty
dolmen
ed
ether
felipe
gardner
jkeenan
jmates
jraspass
kennedy
leklund
lib
miyagawa
mjegh
mlbright
mrdvt92
nanis
olaf
pearce
ppisar
proxying
rochelemagne
sandals
sanjay
skaji
skymarshal1729
snjkmr32
soeren
steve
stro
syohex
tom
tony
wolfsage
xdg
yadd
